]> git.marmaro.de Git - mmh/commitdiff
Removed the `mhbuild' indirection via `buildmimeproc'.
authormarkus schnalke <meillo@marmaro.de>
Thu, 22 Mar 2012 10:03:52 +0000 (11:03 +0100)
committermarkus schnalke <meillo@marmaro.de>
Thu, 22 Mar 2012 10:03:52 +0000 (11:03 +0100)
We expect BINDIR to be in PATH if one executes mmh programs.

config/config.c
h/mh.h
man/mh-profile.man5
sbr/readconfig.c
uip/mhparam.c
uip/send.c

index e9b3f2b3f7c108c0632865519d2e6f330b7cadbd..e51397ad5a6255a514e02152e4cd8b6f0f548695 100644 (file)
@@ -111,11 +111,6 @@ char *mimetypequeryproc = "file -b --mime";
 ** nmh default programs
 */
 
-/*
-** This is the program to process MIME composition files
-*/
-char *buildmimeproc = NMHBINDIR"/mhbuild";
-
 /*
 ** This program is usually called directly by users, but it is
 ** also invoked by the spost program to process an "Fcc", or by
diff --git a/h/mh.h b/h/mh.h
index 026f0dcf32afd9d834152868a83cef279a55c322..ced6c77a848ce843cdce60c06de5a45c18a6dc6c 100644 (file)
--- a/h/mh.h
+++ b/h/mh.h
@@ -286,7 +286,6 @@ extern char *mailstore;      /* name of mail storage directory  */
 ** on any system.
 */
 extern char *attach_hdr;
-extern char *buildmimeproc;
 extern char *backup_prefix;
 extern char *altmsglink;
 extern char *components;
index dc37bb990c8e9b24e8a0c82b7c873148baa27e28..b5e731ab23c15cb3b0e51739238cf1276300b77d 100644 (file)
@@ -392,15 +392,6 @@ The profile can be used to select alternate programs if the
 user wishes.  The default values are given in the examples.
 .RE
 .PP
-.BR buildmimeproc :
-%bindir%/mhbuild
-.RS 5
-This is the program used by
-.B send
-to process MIME composition files, created from drafts which require
-MIME features.
-.RE
-.PP
 .BR fileproc :
 %bindir%/refile
 .RS 5
index 048ae4ba57641db18f34bd2c5bcbee4cc2113f61..daa25099b5f1f753caf278af865c9a5df82edb1e 100644 (file)
@@ -22,7 +22,6 @@ static struct procstr procs[] = {
        { "backup-prefix", &backup_prefix },
        { "draft-folder",  &draftfolder },
        { "altmsg-link",   &altmsglink },
-       { "buildmimeproc", &buildmimeproc },
        { "fileproc",      &fileproc },
        { "incproc",       &incproc },
        { "lproc",         &lproc },
index 0f9c487c761d628a5ce2dc2ea31b29b6df4833d7..2d78cd95f2026e1444ee803f6ca0e565d65e49e3 100644 (file)
@@ -36,7 +36,6 @@ static struct proc procs [] = {
        { "attachment-header",  &attach_hdr },
        { "context",       &context },
        { "mh-sequences",  &mh_seq },
-       { "buildmimeproc", &buildmimeproc },
        { "editor",        &defaulteditor },
        { "fileproc",      &fileproc },
        { "foldprot",      &foldprot },
index 2ef1fe765356ea37ed27945b2f4e80c96b68de66..09bbcf80d3be08683dada94a2b834f297c38399c 100644 (file)
@@ -485,7 +485,7 @@ attach(char *draft_file_name)
                fclose(body_file);
 
                /* Add a mhbuild MIME composition file line for the body */
/* charset will be discovered/guessed by buildmimeproc */
                fprintf(composition_file, "#text/plain %s\n", body_file_name);
        }
 
@@ -512,11 +512,8 @@ attach(char *draft_file_name)
        }
        fclose(composition_file);
 
-       /*
-       ** We're ready to roll!  Run mhbuild on the composition file.
-       ** Note that mhbuild is in the context as buildmimeproc.
-       */
-       sprintf(buf, "%s %s", buildmimeproc, composition_file_name);
+       /* We're ready to roll! */
+       sprintf(buf, "mhbuild %s", composition_file_name);
        if (system(buf) != 0) {
                /* some problem */
                clean_up_temporary_files();
@@ -485,7 +485,7 @@ attach(char *draft_file_name)
 
                /* Add a mhbuild MIME composition file line for the body */
-               /* charset will be discovered/guessed by buildmimeproc */
+               /* charset will be discovered/guessed by mhbuild */
                fprintf(composition_file, "#text/plain %s\n", body_file_name);
        }